helpers

package
v0.38.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: GPL-3.0 Imports: 6 Imported by: 3

Documentation

Overview

Copyright (C) 2020-2025 Daniele Rondina <geaaru@macaronios.org> Credits goes also to Gogs authors, some code portions and re-implemented design are also coming from the Gogs project, which is using the go-macaron framework and was really source of ispiration. Kudos to them!

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

Copyright (C) 2020-2025 Daniele Rondina <geaaru@macaronios.org> Credits goes also to Gogs authors, some code portions and re-implemented design are also coming from the Gogs project, which is using the go-macaron framework and was really source of ispiration. Kudos to them!

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Ask added in v0.31.0

func Ask(msg string) bool

func Exists added in v0.7.0

func Exists(name string) bool

Exists reports whether the named file or directory exists.

func RegexEntry added in v0.10.0

func RegexEntry(regexString string, listEntries []string) []string

Types

type NopCloseWriter

type NopCloseWriter struct {
	*bytes.Buffer
}

func NewNopCloseWriter

func NewNopCloseWriter(buf *bytes.Buffer) *NopCloseWriter

func (*NopCloseWriter) Close

func (ncw *NopCloseWriter) Close() error

Directories

Path Synopsis

Jump to